@@ -66,104 +66,104 @@ const QStringList kwin_active_effects = {"blur", "scissor"};
 
 // deepin-wm's accel as Key
 static QMap<QString, QString> AllDeepinWMKWinAccelsMap {
-    { "switch-to-workspace-1", "Switch to Desktop 1" },
-    { "switch-to-workspace-2", "Switch to Desktop 2" },
-    { "switch-to-workspace-3", "Switch to Desktop 3" },
-    { "switch-to-workspace-4", "Switch to Desktop 4" },
-    { "switch-to-workspace-5", "Switch to Desktop 5" },
-    { "switch-to-workspace-6", "Switch to Desktop 6" },
-    { "switch-to-workspace-7", "Switch to Desktop 7" },
-    { "switch-to-workspace-8", "Switch to Desktop 8" },
-    { "switch-to-workspace-9", "Switch to Desktop 9" },
-    { "switch-to-workspace-10", "Switch to Desktop 10" },
-    { "switch-to-workspace-11", "Switch to Desktop 11" },
-    { "switch-to-workspace-12", "Switch to Desktop 12" },
-    { "switch-to-workspace-left", "Switch to Previous Desktop" },
-    { "switch-to-workspace-right", "Switch to Next Desktop" },
-    { "switch-group", "Walk Through Windows of Current Application" },
-    { "switch-group-backward", "Walk Through Windows of Current Application (Reverse)" },
-    { "switch-applications", "Walk Through Windows" },
-    { "switch-applications-backward", "Walk Through Windows (Reverse)" },
-    { "show-desktop", "Show Desktop" },
-    { "activate-window-menu", "Window Operations Menu" },
-    { "toggle-fullscreen", "Window Fullscreen" },
-    { "toggle-maximized", "Window Maximize" },
-    { "toggle-above", "Toggle Window Raise/Lower" },
+    { "switchToWorkspace1", "Switch to Desktop 1" },
+    { "switchToWorkspace2", "Switch to Desktop 2" },
+    { "switchToWorkspace3", "Switch to Desktop 3" },
+    { "switchToWorkspace4", "Switch to Desktop 4" },
+    { "switchToWorkspace5", "Switch to Desktop 5" },
+    { "switchToWorkspace6", "Switch to Desktop 6" },
+    { "switchToWorkspace7", "Switch to Desktop 7" },
+    { "switchToWorkspace8", "Switch to Desktop 8" },
+    { "switchToWorkspace9", "Switch to Desktop 9" },
+    { "switchToWorkspace10", "Switch to Desktop 10" },
+    { "switchToWorkspace11", "Switch to Desktop 11" },
+    { "switchToWorkspace12", "Switch to Desktop 12" },
+    { "switchToWorkspaceLeft", "Switch to Previous Desktop" },
+    { "switchToWorkspaceRight", "Switch to Next Desktop" },
+    { "switchGroup", "Walk Through Windows of Current Application" },
+    { "switchGroupBackward", "Walk Through Windows of Current Application (Reverse)" },
+    { "switchApplications", "Walk Through Windows" },
+    { "switchApplicationsBackward", "Walk Through Windows (Reverse)" },
+    { "showDesktop", "Show Desktop" },
+    { "activateWindowMenu", "Window Operations Menu" },
+    { "toggleFullscreen", "Window Fullscreen" },
+    { "toggleMaximized", "Window Maximize" },
+    { "toggleAbove", "Toggle Window Raise/Lower" },
     { "maximize", "Window Absolute Maximize" },
     { "unmaximize", "Window Unmaximize" },
     { "minimize", "Window Minimize" },
     { "close", "Window Close" },
-    { "begin-move", "Window Move" },
-    { "begin-resize", "Window Resize" },
-    { "toggle-to-left", "Window Quick Tile Left" },
-    { "toggle-to-right", "Window Quick Tile Right" },
-    { "move-to-workspace-1", "Window to Desktop 1" },
-    { "move-to-workspace-2", "Window to Desktop 2" },
-    { "move-to-workspace-3", "Window to Desktop 3" },
-    { "move-to-workspace-4", "Window to Desktop 4" },
-    { "move-to-workspace-5", "Window to Desktop 5" },
-    { "move-to-workspace-6", "Window to Desktop 6" },
-    { "move-to-workspace-7", "Window to Desktop 7" },
-    { "move-to-workspace-8", "Window to Desktop 8" },
-    { "move-to-workspace-9", "Window to Desktop 9" },
-    { "move-to-workspace-10", "Window to Desktop 10" },
-    { "move-to-workspace-11", "Window to Desktop 11" },
-    { "move-to-workspace-12", "Window to Desktop 12" },
-    { "move-to-workspace-left", "Window to Previous Desktop" },
-    { "move-to-workspace-right", "Window to Next Desktop" },
-    { "maximize-vertically", "Window Maximize Vertical" },
-    { "maximize-horizontally", "Window Maximize Horizontal" },
-    { "expose-all-windows", "ExposeAll" },
-    { "expose-windows", "Expose" },
-    { "preview-workspace", "ShowMultitasking" },
-    { "view-zoom-in", "view_zoom_in" },
-    { "view-zoom-out", "view_zoom_out" },
-    { "view-actual-size", "view_actual_size" },
+    { "beginMove", "Window Move" },
+    { "beginResize", "Window Resize" },
+    { "toggleToLeft", "Window Quick Tile Left" },
+    { "toggleToRight", "Window Quick Tile Right" },
+    { "moveToWorkspace1", "Window to Desktop 1" },
+    { "moveToWorkspace2", "Window to Desktop 2" },
+    { "moveToWorkspace3", "Window to Desktop 3" },
+    { "moveToWorkspace4", "Window to Desktop 4" },
+    { "moveToWorkspace5", "Window to Desktop 5" },
+    { "moveToWorkspace6", "Window to Desktop 6" },
+    { "moveToWorkspace7", "Window to Desktop 7" },
+    { "moveToWorkspace8", "Window to Desktop 8" },
+    { "moveToWorkspace9", "Window to Desktop 9" },
+    { "moveToWorkspace10", "Window to Desktop 10" },
+    { "moveToWorkspace11", "Window to Desktop 11" },
+    { "moveToWorkspace12", "Window to Desktop 12" },
+    { "moveToWorkspaceLeft", "Window to Previous Desktop" },
+    { "moveToWorkspaceRight", "Window to Next Desktop" },
+    { "maximizeVertically", "Window Maximize Vertical" },
+    { "maximizeHorizontally", "Window Maximize Horizontal" },
+    { "exposeAllWindows", "ExposeAll" },
+    { "exposeWindows", "Expose" },
+    { "previewWorkspace", "ShowMultitasking" },
+    { "viewZoomIn", "view_zoom_in" },
+    { "viewZoomOut", "view_zoom_out" },
+    { "viewActualSize", "view_actual_size" },
 };
 
 static const QMap<QString, QString> WaylandDeepinWMKWinAccelsMap {
     { "launcher" , "Launcher"},
     { "terminal" , "Terminal"},
-    { "deepin-screen-recorder", "Screen Recorder"},
-    { "lock-screen",            "Lock screen"},
-    { "show-dock",              "Show/Hide the dock"},
+    { "deepinScreenRecorder", "Screen Recorder"},
+    { "lockScreen",            "Lock screen"},
+    { "showDock",              "Show/Hide the dock"},
     { "logout",                 "Shutdown interface"},
-    { "terminal-quake",         "Terminal Quake Window"},
+    { "terminalQuake",         "Terminal Quake Window"},
     { "screenshot",             "Screenshot"},
-    { "screenshot-fullscreen",  "Full screenshot"},
-    { "screenshot-window",      "Window screenshot"},
-    { "screenshot-delayed",     "Delay screenshot"},
-    { "file-manager",           "File manager"},
-    { "disable-touchpad",       "Disable Touchpad"},
-    { "wm-switcher",            "Switch window effects"},
-    { "turn-off-screen",        "Fast Screen Off"},
-    { "system-monitor",         "System Monitor"},
-    { "color-picker",           "Deepin Picker"},
-    { "ai-assistant",           "Desktop AI Assistant"},
-    { "text-to-speech",         "Text to Speech"},
-    { "speech-to-text",         "Speech to Text"},
+    { "screenshotFullscreen",  "Full screenshot"},
+    { "screenshotWindow",      "Window screenshot"},
+    { "screenshotDelayed",     "Delay screenshot"},
+    { "fileManager",           "File manager"},
+    { "disableTouchpad",       "Disable Touchpad"},
+    { "wmSwitcher",            "Switch window effects"},
+    { "turnOffScreen",        "Fast Screen Off"},
+    { "systemMonitor",         "System Monitor"},
+    { "colorPicker",           "Deepin Picker"},
+    { "aiAssistant",           "Desktop AI Assistant"},
+    { "textToSpeech",         "Text to Speech"},
+    { "speechToText",         "Speech to Text"},
     { "clipboard",              "Clipboard"},
     { "translation",            "Translation"},
     { "messenger",              "Messenger"},
     { "save",                   "Save"},
     { "new",                    "New"},
-    { "wake-up",                "WakeUp"},
-    { "audio-rewind",           "AudioRewind"},
-    { "audio-mute",             "VolumeMute"},
-    { "mon-brightness-up",      "MonBrightnessUp"},//mon-brightness-up
+    { "wakeUp",                "WakeUp"},
+    { "audioRewind",           "AudioRewind"},
+    { "audioMute",             "VolumeMute"},
+    { "monBrightnessUp",      "MonBrightnessUp"},//monBrightnessUp
     { "wlan",                   "WLAN"},
-    { "audio-media",            "AudioMedia"},
+    { "audioMedia",            "AudioMedia"},
     { "reply",                  "Reply"},
     { "favorites",              "Favorites"},
-    { "audio-play",             "AudioPlay"},
-    { "audio-mic-mute",         "AudioMicMute"},
-    { "audio-pause",            "AudioPause"},
-    { "audio-stop",             "AudioStop"},
-    { "power-off",              "PowerOff"},
+    { "audioPlay",             "AudioPlay"},
+    { "audioMicMute",         "AudioMicMute"},
+    { "audioPause",            "AudioPause"},
+    { "audioStop",             "AudioStop"},
+    { "powerOff",              "PowerOff"},
     { "documents",              "Documents"},
     { "game",                   "Game"},
     { "search",                 "Search"},
-    { "audio-record",           "AudioRecord"},
+    { "audioRecord",           "AudioRecord"},
     { "display",                "Display"},
     { "reload",                 "Reload"},
     { "explorer",               "Explorer"},
@@ -171,38 +171,38 @@ static const QMap<QString, QString> WaylandDeepinWMKWinAccelsMap {
     { "calendar",               "Calendar"},
     { "forward",                "Forward"},
     { "cut",                    "Cut"},
-    { "mon-brightness-down",    "MonBrightnessDown"},
+    { "monBrightnessDown",    "MonBrightnessDown"},
     { "copy",                   "Copy"},
     { "tools",                  "Tools"},
-    { "audio-raise-volume",     "VolumeUp"},
-    { "media-close",            "Media Close"},
+    { "audioRaiseVolume",     "VolumeUp"},
+    { "mediaClose",            "Media Close"},
     { "www",                    "WWW"},
-    { "home-page",              "HomePage"},
+    { "homePage",              "HomePage"},
     { "sleep",                  "Sleep"},
-    { "audio-lower-volume",     "VolumeDown"},
-    { "audio-prev",             "AudioPrev"},
-    { "audio-next",             "AudioNext"},
+    { "audioLowerVolume",     "VolumeDown"},
+    { "audioPrev",             "AudioPrev"},
+    { "audioNext",             "AudioNext"},
     { "paste",                  "Paste"},
     { "open",                   "Open"},
     { "send",                   "Send"},
-    { "my-computer",            "MyComputer"},
+    { "myComputer",            "MyComputer"},
     { "mail",                   "Mail"},
-    { "adjust-brightness",      "BrightnessAdjust"},
-    { "log-off",                "LogOff"},
+    { "adjustBrightness",      "BrightnessAdjust"},
+    { "logOff",                "LogOff"},
     { "pictures",               "Pictures"},
     { "terminal",               "Terminal"},
     { "video",                  "Video"},
     { "music",                  "Music"},
-    { "app-left",               "ApplicationLeft"},
-    { "app-right",              "ApplicationRight"},
+    { "appLeft",               "ApplicationLeft"},
+    { "appRight",              "ApplicationRight"},
     { "meeting",                "Meeting"},
-    { "switch-monitors",        "Switch monitors"},
+    { "switchMonitors",        "Switch monitors"},
     { "capslock",               "Capslock"},
     { "numlock",                "Numlock"},
-    { "notification-center",    "Notification Center"},
-    { "screenshot-ocr",    "ScreenshotOcr"},
-    { "screenshot-scroll",    "ScreenshotScroll"},
-    { "global-search",    "Global Search"},
+    { "notificationCenter",    "Notification Center"},
+    { "screenshotOcr",    "ScreenshotOcr"},
+    { "screenshotScroll",    "ScreenshotScroll"},
+    { "globalSearch",    "Global Search"},
 };
 
 
