@@ -3,6 +3,10 @@
 <TS version="2.1" language="en_US">
 <context>
     <name>AppearanceManager</name>
+    <message>
+        <source>Start setting display scaling, please wait patiently</source>
+        <translation type="unfinished"></translation>
+    </message>
     <message>
         <source>Display scaling</source>
         <translation type="unfinished"></translation>
@@ -23,8 +27,11 @@
         <source>Later</source>
         <translation type="unfinished"></translation>
     </message>
+</context>
+<context>
+    <name>QObject</name>
     <message>
-        <source>Start setting display scaling, please wait patience</source>
+        <source>This system wallpaper is locked. Please contact your admin.</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
